
"""
    my-PV API Python Examples

    © my-PV GmbH - 2024 - api.my-pv.com
"""
import requests

# Define the API endpoint
SERIALNUMBER = '2001001234567890'
API_TOKEN = 'XXXXXXXXXXXXXXXXXXXXXXXXXXX'


# Define the headers, including the token for authentication
HEADERS = {
    'Authorization': f'Bearer {API_TOKEN}',
    'Content-Type': 'application/json',
    'Accept': 'application/json'
}


def setPower(power_W):
    """
        Send a PUT request to set the power.
    """
    url = f'https://api.my-pv.com/api/v1/device/{SERIALNUMBER}/power'

    # Define the data to be sent in the PUT request
    data = {
        "power": power_W,
        "validForMinutes": 10,
        "timeBoostOverride": 0,
        "timeBoostValue": 0,
        "legionellaBoostBlock": 1
    }

    # Make the PUT request
    response = requests.put(url, headers=HEADERS, json=data)

    # Check the response
    if response.status_code == 200:
        print(f'Success: PUT power={power_W}:', response.json())
    else:
        print(f'Failure: PUT power={power_W}:', response.status_code, response.text)


def getDataProperty(fieldName):
    """
        Access the data endpoint and get one element identified by fieldName.
    """
    url = f'https://api.my-pv.com/api/v1/device/{SERIALNUMBER}/data'

    response = requests.get(url, headers=HEADERS)

    if response.status_code == 200:
        try:
            print(f'Success: GET {fieldName}:', response.json()[fieldName])
        except KeyError as ke:
            print(f'KeyError: key "{fieldName}" not found. Update your device first.')
    else:
        print(f'Failure: GET {fieldName}:', response.status_code, response.text)


def checkIfFirmwareIsCompatible():
    """
        Check if the firmware of the given serialnumber is compatible for API usage.
    """
    url = f'https://api.my-pv.com/api/v1/device/{SERIALNUMBER}/isFirmwareCompatible'

    response = requests.get(url, headers=HEADERS)

    if response.status_code == 200:
        if response.json()['isFirmwareCompatible'] == 'false':
            raise(f'Failure: Firmware is not compatible. Quitting.', response.status_code, response.text)
        print(f'Success: Firmware of {SERIALNUMBER} is compatible')


if __name__ == "__main__":
    checkIfFirmwareIsCompatible()
    getDataProperty('power_nominal')  # Get nominal power of the heating element, depends on the configured main mode.
    getDataProperty('power_max')  # Find the maximum currently controllable power, including slaves, excluding external devices (ecar, heatpump,...).
    getDataProperty('p_max_current_incl_slaves')  # Get maximum power including slaves.
    getDataProperty('ctrlstate')  # Get control state of the device.
    setPower(power_W = 3000)
